@@ -5,6 +5,12 @@
 
 # from examples.openai import images_generate
 # from examples.openai.function_calling import function_calling
+# from examples.openai.tool_calling_nonstreaming import run_conversation
+# from examples.openai.async_tool_calling_nonstreaming import run_conversation
+
+# from examples.openai.tool_calling_streaming import run_conversation
+from examples.openai.async_tool_calling_streaming import run_conversation
+
 # from examples.anthropic_example.completion import messages_create
 
 # from examples.pinecone_example.basic import basic
@@ -13,7 +19,7 @@
 # from examples.langchain_example.basic import basic
 # from examples.cohere_example.chat import chat_comp
 # from examples.cohere_example.embed_create import embed_create
-from examples.hiveagent_example.basic import basic
+# from examples.hiveagent_example.basic import basic
 
 # from examples.cohere_example.chat_stream import chat_stream
 
@@ -21,7 +27,7 @@ from examples.hiveagent_example.basic import basic
 
 # load_and_split()
 # rag()
-basic()
+# basic()
 # chat_completion()
 # function_calling()
 # images_generate()
@@ -30,3 +36,9 @@ basic()
 # chat_comp()
 # embed_create()
 # chat_stream()
+
+# for async functions, use asyncio.run()
+import asyncio
+asyncio.run(run_conversation())
+
+# run_conversation()
\ No newline at end of file
